# [Google Earth Engine Batch Asset Manager with Addons](https://samapriya.github.io/gee_asset_manager_addon/)

[![LinkedIn](https://img.shields.io/badge/LinkedIn-0077B5?style=plastic&logo=linkedin&logoColor=white)](https://www.linkedin.com/in/samapriya/)
[![Medium](https://img.shields.io/badge/Medium-12100E?style=flat&logo=medium&logoColor=white)](https://medium.com/@samapriyaroy)
[![Twitter URL](https://img.shields.io/twitter/follow/samapriyaroy?style=social)](https://twitter.com/intent/follow?screen_name=samapriyaroy)
[![Mastodon Follow](https://img.shields.io/mastodon/follow/109627075086849826?domain=https%3A%2F%2Fmapstodon.space%2F)](https://mapstodon.space/@samapriya)
[![Hits-of-Code](https://hitsofcode.com/github/samapriya/gee_asset_manager_addon?branch=master)](https://hitsofcode.com/github/samapriya/gee_asset_manager_addon?branch=master)
![PyPI - Version](https://img.shields.io/pypi/v/geeadd)
[![Downloads](https://static.pepy.tech/badge/geeadd/month)](https://pepy.tech/project/geeadd)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.11482497.svg)](https://doi.org/10.5281/zenodo.11482497)
![CI geeadd](https://github.com/samapriya/gee_asset_manager_addon/workflows/CI%20geeadd/badge.svg)
[![Donate](https://img.shields.io/badge/Donate-Buy%20me%20a%20Chai-teal)](https://www.buymeacoffee.com/samapriya)
[![](https://img.shields.io/static/v1?label=Sponsor&message=%E2%9D%A4&logo=GitHub&color=%23fe8e86)](https://github.com/sponsors/samapriya)

**geeadd** (which stands for **Google Earth Engine** batch asset manager with **addons** ) provides a command-line tool for managing Google Earth Engine assets in batch. It allows you to perform a variety of operations on your assets that add to the existing earthengine command line tool. This includes tools that allows a user to estimate their quota usage, asset sizes, set permissions on assets, move and copy and many others. There are also some functions that are build to provided extended functionality like convert any earth engine app script to the source code and search tool which allows you to search both the GEE official data catalog and the community catalog.

This project has been a lot of work starting a few years ago and current improvements and updates can be seen reflected in v1.0.0 and higher up.

![geeadd_main](https://github.com/samapriya/gee_asset_manager_addon/assets/6677629/bf795033-5d5f-40fb-b767-ca87379b9cce)

Like, share and support the Github project. And you can now cite it too

<b>

```
Samapriya Roy, & Biplov Bhandari. (2024). samapriya/gee_asset_manager_addon: GEE Asset Manager with Addons (1.2.0).
Zenodo. https://doi.org/10.5281/zenodo.11482497
```

</b>

Find the [readme docs here](https://geeadd.geetools.xyz)
